public class Bank
{
	private BankAccount first;
	private BankAccount second;
	
    public Bank()
    {
		first = new BankAccount( "John", 1000.00 );
		second = new BankAccount( "Marsha" );
    }
	
	/**
	 * Returns the BankAccount that matches the name parameter;
	 * Returns null if the account does not exist
	 */
	
	private BankAccount findAccount( String name )
	{
		if ( name.equalsIgnoreCase( "John" ) )
		{
			return this.first;
		}
		else if ( name.equalsIgnoreCase( "Marsha" ) )
		{
			return this.second;
		}
		else
		{
			return null;
		}
	}
    
    /**
     * Returns the balance of the account with the account name accountName;
     * Returns Double.NaN (not a number) if the account doesn't exist
     */
    public double getBalance( String accountName )
    {
		BankAccount temp;
		temp = findAccount( accountName );
		if ( temp == null )
		{
			return Double.NaN;
		}
		else
		{
			return temp.getBalance();
		}
    }
    
    /**
     * Deposits the amount to the account with the account name accountName;
     * Returns true if successful, false if not
     */
    public boolean deposit( String accountName, double amount )
    {
		BankAccount temp;
		temp = findAccount( accountName );
		if ( temp == null )
		{
			return false;
		}
		else
		{
			temp.deposit( amount );
			return true;
		}
    }
    
    /**
     * Withdraws the amount to the account with the account name accountName;
     * Returns true if successful, false if not
     */
    public boolean withdraw( String accountName, double amount )
    {
		BankAccount temp;
		temp = findAccount( accountName );
		if ( temp == null )
		{
			return false;
		}
		else
		{
			temp.withdraw( amount );
			return true;
		}
    }
    
    /**
     * Withdraw amount from the account named srcAccountName 
     * and transfer it to the account named destAccountName.
     * Returns true if successful, false if not.
     */
    public boolean transfer( String srcAccountName, String destAccountName, double amount )
    {
		BankAccount source;
		BankAccount destination;
		source = findAccount( srcAccountName );
		destination = findAccount( destAccountName );
		if ( source == null || destination == null )
		{
			return false;
		}
		else
		{
			source.withdraw( amount );
			destination.deposit( amount );
			return true;
		}
    }
    
    /**
     * Prints information on all the accounts to the console.
     */
    public void printAllAccounts()
    {
		System.out.println( first );
		System.out.println( second );
    }
}
